package com.diagbot.rule;

import com.diagbot.biz.push.entity.Item;
import com.diagbot.dto.BillMsg;
import com.diagbot.dto.BillNeoMaxDTO;
import com.diagbot.dto.NodeNeoDTO;
import com.diagbot.dto.WordCrfDTO;
import com.diagbot.util.MsgUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @description: 人群规则
 * @author: zhoutg
 * @time: 2020/8/3 14:47
 */
@Component
public class GroupRule {

    /**
     * 禁忌人群
     *
     * @param wordCrfDTO
     * @param billNeoMaxDTO
     * @return
     */
    public void bill(WordCrfDTO wordCrfDTO, BillNeoMaxDTO billNeoMaxDTO, List<BillMsg> billMsgList, String type) {
        List<NodeNeoDTO> group = billNeoMaxDTO.getGroup();
        Double age = wordCrfDTO.getAgeNum();
        for (NodeNeoDTO node : group) {
            // 妊娠目前从诊断里判断,包含“妊娠”
            String symptom = wordCrfDTO.getSymptom(); // 现病史内容
            switch (node.getName()) {
                case "妊娠":
                    // 现病史包含“孕妇”
                    if (symptom.contains("孕妇")) {
                        BillMsg commonBillMsg = MsgUtil.getCommonBillMsg(
                                billNeoMaxDTO.getOrderName(), billNeoMaxDTO.getOrderStandName(),
                                "妊娠", type, billNeoMaxDTO.getType());
                        billMsgList.add(commonBillMsg);
                    }
                    // 诊断里包含“妊娠” 或者 包含“孕几周”
                    List<Item> diag = wordCrfDTO.getDiag();
                    for (Item item : diag) {
                        if (item.getUniqueName().contains("妊娠")) {
                            BillMsg commonBillMsg = MsgUtil.getCommonBillMsg(
                                    billNeoMaxDTO.getOrderName(), billNeoMaxDTO.getOrderStandName(),
                                    item.getUniqueName(), type, billNeoMaxDTO.getType());
                            billMsgList.add(commonBillMsg);
                        } else {
                            String regex = "孕.{1,4}周.*"; // 孕xx周
                            if (item.getUniqueName().matches(regex)) {
                                BillMsg commonBillMsg = MsgUtil.getCommonBillMsg(
                                        billNeoMaxDTO.getOrderName(), billNeoMaxDTO.getOrderStandName(),
                                        item.getUniqueName(), type, billNeoMaxDTO.getType());
                                billMsgList.add(commonBillMsg);
                            }
                        }
                    }
                    break;
                case "月经期":
                    String regex = "月经第(([零一二三四五六七八九十]{0,3})||([0-9]{0,2}))天";
                    Pattern pattern = Pattern.compile(regex);
                    Matcher matcher = pattern.matcher(symptom);
                    boolean rs = matcher.find();
                    if (rs) {
                        BillMsg commonBillMsg = MsgUtil.getCommonBillMsg(
                                billNeoMaxDTO.getOrderName(), billNeoMaxDTO.getOrderStandName(),
                                "月经期", type, billNeoMaxDTO.getType());
                        billMsgList.add(commonBillMsg);
                    }
                    break;
                case "幼儿":
                    if (age != null) {
                        if (age < 6.0D && 1.0D <= age) {
                            BillMsg commonBillMsg = MsgUtil.getCommonBillMsg(
                                    billNeoMaxDTO.getOrderName(), billNeoMaxDTO.getOrderStandName(),
                                    "幼儿", type, billNeoMaxDTO.getType());
                            billMsgList.add(commonBillMsg);
                        }
                    }
                    break;
                case "儿童":
                    if (age != null) {
                        if (age < 18.0D && age >= 6.0D) {
                            BillMsg commonBillMsg = MsgUtil.getCommonBillMsg(
                                    billNeoMaxDTO.getOrderName(), billNeoMaxDTO.getOrderStandName(),
                                    "儿童", type, billNeoMaxDTO.getType());
                            billMsgList.add(commonBillMsg);
                        }
                    }
                    break;
            }
        }
    }
}
